@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 import hashlib
+import struct
 
 from smda.intel.IntelInstructionEscaper import IntelInstructionEscaper
 from smda.common.Tarjan import Tarjan
@@ -72,6 +73,12 @@ class SmdaFunction(object):
         for _, block in sorted(self.blocks.items()):
             yield block
 
+    def getPicHashAsLong(self):
+        return self.pic_hash
+
+    def getPicHashAsHex(self):
+        return struct.pack("l", self.pic_hash).hex()
+
     def getInstructions(self):
         for block in self.getBlocks():
             for ins in block:
@@ -112,7 +119,7 @@ class SmdaFunction(object):
         smda_function.offset = function_dict["offset"]
         smda_function.blocks = {}
         for addr, block in function_dict["blocks"].items():
-            smda_function.blocks[addr] = [SmdaInstruction.fromDict(ins) for ins in block]
+            smda_function.blocks[int(addr)] = [SmdaInstruction.fromDict(ins) for ins in block]
         smda_function.apirefs = {int(k): v for k, v in function_dict["apirefs"].items()}
         smda_function.blockrefs = {int(k): v for k, v in function_dict["blockrefs"].items()}
         smda_function.inrefs = function_dict["inrefs"]
